@@ -387,19 +387,12 @@ CK_RV NSC_GetInterface(CK_UTF8CHAR_PTR pInterfaceName,
 char **NSC_ModuleDBFunc(unsigned long function, char *parameters, void *args);
 #endif
 
-/*
- * load a new module into our address space and initialize it.
- */
 SECStatus
-secmod_LoadPKCS11Module(SECMODModule *mod, SECMODModule **oldModule)
+secmod_DetermineModuleFunctionList(SECMODModule *mod)
 {
     PRLibrary *library = NULL;
     CK_C_GetInterface ientry = NULL;
     CK_C_GetFunctionList fentry = NULL;
-    CK_INFO info;
-    CK_ULONG slotCount = 0;
-    SECStatus rv;
-    PRBool alreadyLoaded = PR_FALSE;
     char *disableUnload = NULL;
 #ifndef NSS_STATIC_SOFTOKEN
     const char *nss_interface;
@@ -407,11 +400,6 @@ secmod_LoadPKCS11Module(SECMODModule *mod, SECMODModule **oldModule)
 #endif
     CK_INTERFACE_PTR interface;
 
-    if (mod->loaded)
-        return SECSuccess;
-
-    mod->fipsIndicator = NULL;
-
     /* internal modules get loaded from their internal list */
     if (mod->internal && (mod->dllName == NULL)) {
 #ifdef NSS_STATIC_SOFTOKEN
@@ -553,6 +541,25 @@ secmod_LoadPKCS11Module(SECMODModule *mod, SECMODModule **oldModule)
     }
 #endif
 
+    return SECSuccess;
+
+fail:
+    mod->functionList = NULL;
+    disableUnload = PR_GetEnvSecure("NSS_DISABLE_UNLOAD");
+    if (library && !disableUnload) {
+        PR_UnloadLibrary(library);
+    }
+    return SECFailure;
+}
+
+SECStatus
+secmod_InitializeModuleAndGetSlotInfo(SECMODModule *mod, SECMODModule **oldModule)
+{
+    CK_INFO info;
+    CK_ULONG slotCount = 0;
+    SECStatus rv;
+    PRBool alreadyLoaded = PR_FALSE;
+
     /* This test operation makes sure our locking system is
      * consistent even if we are using non-thread safe tokens by
      * simulating unsafe tokens with safe ones. */
@@ -643,13 +650,80 @@ fail2:
     }
 fail:
     mod->functionList = NULL;
-    disableUnload = PR_GetEnvSecure("NSS_DISABLE_UNLOAD");
-    if (library && !disableUnload) {
-        PR_UnloadLibrary(library);
-    }
     return SECFailure;
 }
 
+/*
+ * load a new module into our address space and initialize it.
+ */
+SECStatus
+secmod_LoadPKCS11Module(SECMODModule *mod, SECMODModule **oldModule)
+{
+    SECStatus rv = SECFailure;
+    if (mod->loaded) {
+        return SECSuccess;
+    }
+
+    mod->fipsIndicator = NULL;
+
+    rv = secmod_DetermineModuleFunctionList(mod);
+    if (rv != SECSuccess) { // The error code is set up by secmod_DetermineModuleFunctionList.
+        return rv;
+    }
+
+    if (mod->loaded == PR_TRUE) {
+        return SECSuccess;
+    }
+
+    rv = secmod_InitializeModuleAndGetSlotInfo(mod, oldModule);
+    if (rv != SECSuccess) { // The error code is set up by secmod_InitializeModuleAndGetSlotInfo
+        return rv;
+    }
+
+    return SECSuccess;
+}
+
+/*
+ * load a new module using provided fentry function
+ */
+SECStatus
+secmod_LoadPKCS11ModuleFromFunction(SECMODModule *mod, SECMODModule **oldModule,
+                                    CK_C_GetFunctionList fentry)
+{
+    SECStatus rv = SECFailure;
+    CK_RV crv;
+    if (mod->loaded) {
+        return SECSuccess;
+    }
+
+    mod->fipsIndicator = NULL;
+
+    if (!fentry) {
+        PORT_SetError(SEC_ERROR_INVALID_ARGS);
+        return SECFailure;
+    }
+
+    crv = fentry((CK_FUNCTION_LIST_PTR *)&mod->functionList);
+    if (crv != CKR_OK) {
+        mod->functionList = NULL;
+        PORT_SetError(PK11_MapError(crv));
+        return SECFailure;
+    }
+
+    if (mod->functionList == NULL) {
+        PORT_SetError(SEC_ERROR_LIBRARY_FAILURE);
+        return SECFailure;
+    }
+
+    mod->flags = 0;
+    rv = secmod_InitializeModuleAndGetSlotInfo(mod, oldModule);
+    if (rv != SECSuccess) {
+        return rv;
+    }
+
+    return SECSuccess;
+}
+
 SECStatus
 SECMOD_UnloadModule(SECMODModule *mod)
 {
@@ -692,9 +766,9 @@ SECMOD_UnloadModule(SECMODModule *mod)
     }
 
     library = (PRLibrary *)mod->library;
-    /* paranoia */
+    /* if no library, then we should not unload it */
     if (library == NULL) {
-        return SECFailure;
+        return SECSuccess;
     }
 
     disableUnload = PR_GetEnvSecure("NSS_DISABLE_UNLOAD");
