@@ -204,8 +204,8 @@ NSS_CMSSignerInfo_Sign(NSSCMSSignerInfo *signerinfo, SECItem *digest,
         SECOID_DestroyAlgorithmID(&freeAlgID, PR_FALSE);
     }
 
-    signAlgTag = SEC_GetSignatureAlgorithmOidTag(SECKEY_GetPrivateKeyType(privkey),
-                                                 digestalgtag);
+    signAlgTag = SEC_GetSignatureAlgorithmOidTagByKey(privkey, NULL,
+                                                      digestalgtag);
     if (signAlgTag == SEC_OID_UNKNOWN) {
         PORT_SetError(SEC_ERROR_INVALID_ALGORITHM);
         goto loser;
@@ -250,17 +250,17 @@ NSS_CMSSignerInfo_Sign(NSSCMSSignerInfo *signerinfo, SECItem *digest,
         }
 
         /*
-     * Before encoding, reorder the attributes so that when they
-     * are encoded, they will be conforming DER, which is required
-     * to have a specific order and that is what must be used for
-     * the hash/signature.  We do this here, rather than building
-     * it into EncodeAttributes, because we do not want to do
-     * such reordering on incoming messages (which also uses
-     * EncodeAttributes) or our old signatures (and other "broken"
-     * implementations) will not verify.  So, we want to guarantee
-     * that we send out good DER encodings of attributes, but not
-     * to expect to receive them.
-     */
+         * Before encoding, reorder the attributes so that when they
+         * are encoded, they will be conforming DER, which is required
+         * to have a specific order and that is what must be used for
+         * the hash/signature.  We do this here, rather than building
+         * it into EncodeAttributes, because we do not want to do
+         * such reordering on incoming messages (which also uses
+         * EncodeAttributes) or our old signatures (and other "broken"
+         * implementations) will not verify.  So, we want to guarantee
+         * that we send out good DER encodings of attributes, but not
+         * to expect to receive them.
+         */
         if (NSS_CMSAttributeArray_Reorder(signerinfo->authAttr) != SECSuccess)
             goto loser;
 
@@ -391,14 +391,14 @@ NSS_CMSSignerInfo_Verify(NSSCMSSignerInfo *signerinfo,
     if (!NSS_CMSArray_IsEmpty((void **)signerinfo->authAttr)) {
         if (contentType) {
             /*
-         * Check content type
-         *
-         * RFC2630 sez that if there are any authenticated attributes,
-         * then there must be one for content type which matches the
-         * content type of the content being signed, and there must
-         * be one for message digest which matches our message digest.
-         * So check these things first.
-         */
+             * Check content type
+             *
+             * RFC2630 sez that if there are any authenticated attributes,
+             * then there must be one for content type which matches the
+             * content type of the content being signed, and there must
+             * be one for message digest which matches our message digest.
+             * So check these things first.
+             */
             attr = NSS_CMSAttributeArray_FindAttrByOidTag(signerinfo->authAttr,
                                                           SEC_OID_PKCS9_CONTENT_TYPE, PR_TRUE);
             if (attr == NULL) {
@@ -413,8 +413,8 @@ NSS_CMSSignerInfo_Verify(NSSCMSSignerInfo *signerinfo,
         }
 
         /*
-     * Check digest
-     */
+         * Check digest
+         */
         attr = NSS_CMSAttributeArray_FindAttrByOidTag(signerinfo->authAttr,
                                                       SEC_OID_PKCS9_MESSAGE_DIGEST, PR_TRUE);
         if (attr == NULL) {
@@ -433,13 +433,13 @@ NSS_CMSSignerInfo_Verify(NSSCMSSignerInfo *signerinfo,
         }
 
         /*
-     * Check signature
-     *
-     * The signature is based on a digest of the DER-encoded authenticated
-     * attributes.  So, first we encode and then we digest/verify.
-     * we trust the decoder to have the attributes in the right (sorted)
-     * order
-     */
+         * Check signature
+         *
+         * The signature is based on a digest of the DER-encoded authenticated
+         * attributes.  So, first we encode and then we digest/verify.
+         * we trust the decoder to have the attributes in the right (sorted)
+         * order
+         */
         encoded_attrs.data = NULL;
         encoded_attrs.len = 0;
 
@@ -453,8 +453,8 @@ NSS_CMSSignerInfo_Verify(NSSCMSSignerInfo *signerinfo,
 
         if (sigAlgTag == pubkAlgTag) {
             /* This is to handle cases in which signatureAlgorithm field
-	     * specifies the public key algorithm rather than a signature
-	     * algorithm. */
+             * specifies the public key algorithm rather than a signature
+             * algorithm. */
             vs = (VFY_VerifyDataDirect(encoded_attrs.data, encoded_attrs.len,
                                        publickey, &(signerinfo->encDigest), pubkAlgTag,
                                        digestalgtag, NULL, signerinfo->cmsg->pwfn_arg) != SECSuccess)
@@ -480,16 +480,16 @@ NSS_CMSSignerInfo_Verify(NSSCMSSignerInfo *signerinfo,
         SECItem *sig;
 
         /* No authenticated attributes.
-    ** The signature is based on the plain message digest.
-    */
+         ** The signature is based on the plain message digest.
+         */
         sig = &(signerinfo->encDigest);
         if (sig->len == 0)
             goto loser;
 
         if (sigAlgTag == pubkAlgTag) {
             /* This is to handle cases in which signatureAlgorithm field
-	     * specifies the public key algorithm rather than a signature
-	     * algorithm. */
+             * specifies the public key algorithm rather than a signature
+             * algorithm. */
             vs = (!digest ||
                   VFY_VerifyDigestDirect(digest, publickey, sig, pubkAlgTag,
                                          digestalgtag, signerinfo->cmsg->pwfn_arg) != SECSuccess)
@@ -508,26 +508,26 @@ NSS_CMSSignerInfo_Verify(NSSCMSSignerInfo *signerinfo,
     if (vs == NSSCMSVS_BadSignature) {
         int error = PORT_GetError();
         /*
-     * XXX Change the generic error into our specific one, because
-     * in that case we get a better explanation out of the Security
-     * Advisor.  This is really a bug in the PSM error strings (the
-     * "generic" error has a lousy/wrong message associated with it
-     * which assumes the signature verification was done for the
-     * purposes of checking the issuer signature on a certificate)
-     * but this is at least an easy workaround and/or in the
-     * Security Advisor, which specifically checks for the error
-     * SEC_ERROR_PKCS7_BAD_SIGNATURE and gives more explanation
-     * in that case but does not similarly check for
-     * SEC_ERROR_BAD_SIGNATURE.  It probably should, but then would
-     * probably say the wrong thing in the case that it *was* the
-     * certificate signature check that failed during the cert
-     * verification done above.  Our error handling is really a mess.
-     */
+         * XXX Change the generic error into our specific one, because
+         * in that case we get a better explanation out of the Security
+         * Advisor.  This is really a bug in the PSM error strings (the
+         * "generic" error has a lousy/wrong message associated with it
+         * which assumes the signature verification was done for the
+         * purposes of checking the issuer signature on a certificate)
+         * but this is at least an easy workaround and/or in the
+         * Security Advisor, which specifically checks for the error
+         * SEC_ERROR_PKCS7_BAD_SIGNATURE and gives more explanation
+         * in that case but does not similarly check for
+         * SEC_ERROR_BAD_SIGNATURE.  It probably should, but then would
+         * probably say the wrong thing in the case that it *was* the
+         * certificate signature check that failed during the cert
+         * verification done above.  Our error handling is really a mess.
+         */
         if (error == SEC_ERROR_BAD_SIGNATURE)
             PORT_SetError(SEC_ERROR_PKCS7_BAD_SIGNATURE);
         /*
-     * map algorithm failures to NSSCMSVS values
-     */
+         * map algorithm failures to NSSCMSVS values
+         */
         if ((error == SEC_ERROR_PKCS7_KEYALG_MISMATCH) ||
             (error == SEC_ERROR_INVALID_ALGORITHM)) {
             /* keep the same error code as 3.11 and before */
@@ -577,8 +577,8 @@ NSS_CMSSignerInfo_GetDigestAlg(NSSCMSSignerInfo *signerinfo)
     algtag = NSS_CMSUtil_MapSignAlgs(algdata->offset);
     if (algtag != algdata->offset) {
         /* if the tags don't match, then we must have received a signer
-     * algorithID. Now we need to get the oid data for the digest
-     * oid, which the rest of the code is expecting */
+         * algorithID. Now we need to get the oid data for the digest
+         * oid, which the rest of the code is expecting */
         algdata = SECOID_FindOIDByTag(algtag);
     }
 
@@ -1000,7 +1000,7 @@ NSS_SMIMESignerInfo_SaveSMIMEProfile(NSSCMSSignerInfo *signerinfo)
 
     if (cert == NULL) {
         /* no preferred cert found?
-     * find the cert the signerinfo is signed with instead */
+         * find the cert the signerinfo is signed with instead */
         cert = NSS_CMSSignerInfo_GetSigningCertificate(signerinfo, certdb);
         if (cert == NULL || cert->emailAddr == NULL || !cert->emailAddr[0])
             return SECFailure;
@@ -1008,8 +1008,8 @@ NSS_SMIMESignerInfo_SaveSMIMEProfile(NSSCMSSignerInfo *signerinfo)
 
 /* verify this cert for encryption (has been verified for signing so far) */
 /* don't verify this cert for encryption. It may just be a signing cert.
-     * that's OK, we can still save the S/MIME profile. The encryption cert
-     * should have already been saved */
+ * that's OK, we can still save the S/MIME profile. The encryption cert
+ * should have already been saved */
 #ifdef notdef
     if (CERT_VerifyCert(certdb, cert, PR_TRUE, certUsageEmailRecipient, PR_Now(), signerinfo->cmsg->pwfn_arg, NULL) != SECSuccess) {
         if (must_free_cert)
