@@ -559,5 +559,11 @@ ER3(SEC_ERROR_POLICY_LOCKED, (SEC_ERROR_BASE + 180),
 ER3(SEC_ERROR_SIGNATURE_ALGORITHM_DISABLED, (SEC_ERROR_BASE + 181),
     "Could not create or verify a signature using a signature algorithm that is disabled because it is not secure.")
 
-ER3(SEC_ERROR_SIGNATURE_ALGORITHM_DISABLED, (SEC_ERROR_BASE + 181),
+ER3(SEC_ERROR_ALGORITHM_MISMATCH, (SEC_ERROR_BASE + 182),
     "The signature algorithm in the signature field of the certificate does not match the algorithm in its signatureAlgorithm field.")
+
+ER3(SEC_ERROR_CERTIFICATE_COMPRESSION_ALGORITHM_NOT_SUPPORTED, (SEC_ERROR_BASE + 183),
+    "The certificate was encoded using an unsupported certificate compression algorithm.")
+
+ER3(SEC_ERROR_UNEXPECTED_COMPRESSED_CERTIFICATE, (SEC_ERROR_BASE + 184),
+    "Received unexpected compressed certificate.")
